@@ -37,8 +37,8 @@ class MessageComposer::SignatureControllerPrivate
 {
 public:
     SignatureControllerPrivate()
-        : m_editor(Q_NULLPTR),
-          m_identityCombo(Q_NULLPTR),
+        : m_editor(nullptr),
+          m_identityCombo(nullptr),
           m_currentIdentityId(0)
     {
     }
@@ -178,15 +178,3 @@ void SignatureController::applySignature(const KIdentityManagement::Signature &s
         }
     }
 }
-
-void SignatureController::applyCurrentSignature()
-{
-    if (!d->m_identityCombo) {
-        return;
-    }
-    KIdentityManagement::Identity &ident = const_cast<KIdentityManagement::Identity &>(
-            d->m_identityCombo->identityManager()->identityForUoidOrDefault(
-                d->m_identityCombo->currentIdentity()));
-    applySignature(ident.signature());
-}
-
