@@ -46,6 +46,7 @@ RecipientsEditorSideWidget::RecipientsEditorSideWidget(RecipientsEditor *view, Q
 
     mTotalLabel = new QLabel(this);
     mTotalLabel->setAlignment(Qt::AlignCenter);
+    mTotalLabel->setTextFormat(Qt::PlainText);
     topLayout->addWidget(mTotalLabel);
     mTotalLabel->hide();
 
@@ -97,10 +98,11 @@ void RecipientsEditorSideWidget::setTotal(int recipients, int lines)
                                                , "No recipients");
     else labelText = i18ncp("@info:status Number of recipients selected"
                                 , "1 recipient", "%1 recipients", recipients);
-    mTotalLabel->setText(labelText);
 
     if (lines > 3) {
+        mTotalLabel->setText(labelText);
         mTotalLabel->show();
+        updateTotalToolTip();
     } else {
         mTotalLabel->hide();
     }
@@ -111,7 +113,6 @@ void RecipientsEditorSideWidget::setTotal(int recipients, int lines)
         mDistributionListButton->hide();
     }
 
-    updateTotalToolTip();
 }
 
 void RecipientsEditorSideWidget::updateTotalToolTip()
