@@ -37,6 +37,7 @@
 #include <KIdentityManagement/Identity>
 #include <QHostInfo>
 #include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QUrlQuery>
 #include <kpimtextedit/textutils.h>
@@ -205,9 +206,9 @@ QString stripSignature(const QString &msg)
 {
     // Following RFC 3676, only > before --
     // I prefer to not delete a SB instead of delete good mail content.
-    const QRegExp sbDelimiterSearch = QRegExp(QLatin1String("(^|\n)[> ]*-- \n"));
+    const QRegularExpression sbDelimiterSearch(QStringLiteral("(^|\n)[> ]*-- \n"));
     // The regular expression to look for prefix change
-    const QRegExp commonReplySearch = QRegExp(QLatin1String("^[ ]*>"));
+    const QRegularExpression commonReplySearch(QStringLiteral("^[ ]*>"));
 
     QString res = msg;
     int posDeletingStart = 1; // to start looking at 0
@@ -504,9 +505,25 @@ QString smartQuote(const QString &msg, int maxLineLength)
     QString oldIndent;
     bool firstPart = true;
     QString result;
-    const QStringList splitMsgList = msg.split(QLatin1Char('\n'));
-    for (QString line : splitMsgList) {
 
+    int lineStart = 0;
+    int lineEnd = msg.indexOf(QLatin1Char('\n'));
+    bool needToContinue = true;
+    for (;needToContinue; lineStart = lineEnd + 1, lineEnd = msg.indexOf(QLatin1Char('\n'), lineStart)) {
+        QString line;
+        if (lineEnd == -1) {
+            if (lineStart == 0) {
+                line = msg;
+                needToContinue = false;
+            } else if (lineStart != 0 && lineStart != msg.length()) {
+                line = msg.mid(lineStart, msg.length() - lineStart);
+                needToContinue = false;
+            } else {
+                needToContinue = false;
+            }
+        } else {
+            line = msg.mid(lineStart, lineEnd - lineStart);
+        }
         // Split off the indent from the line
         const QString indent = splitLine(line);
 
