@@ -18,17 +18,18 @@
 #ifndef SEARCHLINESTATUS_H
 #define SEARCHLINESTATUS_H
 
-#include <PimCommon/LineEditWithCompleter>
+#include <QLineEdit>
 #include <Akonadi/KMime/MessageStatus>
 #include "messagelist_private_export.h"
 #include "quicksearchline.h"
 #include <QIcon>
+class QStringListModel;
 class QAction;
 namespace MessageList
 {
 namespace Core
 {
-class MESSAGELIST_TESTS_EXPORT SearchLineStatus : public PimCommon::LineEditWithCompleter
+class MESSAGELIST_TESTS_EXPORT SearchLineStatus : public QLineEdit
 {
     Q_OBJECT
 public:
@@ -38,22 +39,27 @@ public:
     void setLocked(bool b);
     bool locked() const;
 
-    void clearFilterAction();
 
     void setContainsOutboundMessages(bool containsOutboundMessages);
     bool containsOutboundMessages() const;
     QuickSearchLine::SearchOptions searchOptions() const;
+    void addCompletionItem(const QString &str);
+    void slotClearHistory();
+    void clearFilterButtonClicked();
 Q_SIGNALS:
     void filterActionChanged(const QList<Akonadi::MessageStatus> &lst);
     void searchOptionChanged();
+    void clearButtonClicked();
+
+protected:
+    void contextMenuEvent(QContextMenuEvent *e) override;
 
 private Q_SLOTS:
     void slotToggledLockAction();
     void showMenu();
-    void clearFilterButtonClicked();
-    void slotSearchOptionChanged();
     void slotFilterActionClicked(QAction *act);
 private:
+    void clearFilterAction();
     void createFilterAction(const QIcon &icon, const QString &text, int value);
     void createMenuSearch();
     void updateLockAction();
@@ -63,6 +69,7 @@ private:
     void createFilterByAction();
     void clearFilterByAction();
     void changeSearchAgainstFromOrToText();
+    void slotClear();
 
     bool mLocked;
     bool mHasFilter;
@@ -77,6 +84,9 @@ private:
     QAction *mSearchAgainstSubjectAction;
     QAction *mSearchAgainstFromOrToAction;
     QAction *mSearchAgainstBccAction;
+    QCompleter *mCompleter;
+    QStringListModel *mCompleterListModel;
+    QStringList mListCompetion;
     bool mContainsOutboundMessages;
 };
 
