@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,14 +24,11 @@
 #include <QByteArray>
 #include <QMap>
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class MailWebEngineView;
 }
 
-namespace MessageViewer
-{
-
+namespace MessageViewer {
 class WebEnginePartHtmlWriter : public QObject, public MimeTreeParser::HtmlWriter
 {
     Q_OBJECT
@@ -39,16 +36,14 @@ public:
     explicit WebEnginePartHtmlWriter(MailWebEngineView *view, QObject *parent = nullptr);
     ~WebEnginePartHtmlWriter();
 
-    void begin(const QString &cssDefs) Q_DECL_OVERRIDE;
-    void end() Q_DECL_OVERRIDE;
-    void reset() Q_DECL_OVERRIDE;
-    void write(const QString &str) Q_DECL_OVERRIDE;
-    void queue(const QString &str) Q_DECL_OVERRIDE;
-    void flush() Q_DECL_OVERRIDE;
-    void embedPart(const QByteArray &contentId, const QString &url) Q_DECL_OVERRIDE;
-    void extraHead(const QString &str) Q_DECL_OVERRIDE;
-
-    static QString removeJscripts(QString str);
+    void begin(const QString &cssDefs) override;
+    void end() override;
+    void reset() override;
+    void write(const QString &str) override;
+    void queue(const QString &str) override;
+    void flush() override;
+    void embedPart(const QByteArray &contentId, const QString &url) override;
+    void extraHead(const QString &str) override;
 
 Q_SIGNALS:
     void finished();
@@ -66,6 +61,5 @@ private:
         Ended
     } mState;
 };
-
 }
 #endif // WEBENGINEPARTHTMLWRITER_H
