@@ -44,17 +44,18 @@ TestJQuerySupportMailWebEngine::TestJQuerySupportMailWebEngine(QWidget *parent)
 
     mEditor = new QTextEdit(this);
     mEditor->setAcceptRichText(false);
-    mEditor->setPlainText(QStringLiteral("qt.jQuery('img').each( function () { qt.jQuery(this).css('-webkit-transition', '-webkit-transform 2s'); qt.jQuery(this).css('-webkit-transform', 'rotate(180deg)') } ); undefined"));
+    mEditor->setPlainText(QStringLiteral(
+                              "qt.jQuery('img').each( function () { qt.jQuery(this).css('-webkit-transition', '-webkit-transform 2s'); qt.jQuery(this).css('-webkit-transform', 'rotate(180deg)') } ); undefined"));
     vboxLayout->addWidget(mEditor);
 
     QPushButton *executeQuery = new QPushButton(QStringLiteral("Execute Query"), this);
-    connect(executeQuery, &QPushButton::clicked, this, &TestJQuerySupportMailWebEngine::slotExecuteQuery);
+    connect(executeQuery, &QPushButton::clicked, this,
+            &TestJQuerySupportMailWebEngine::slotExecuteQuery);
     vboxLayout->addWidget(executeQuery);
 }
 
 TestJQuerySupportMailWebEngine::~TestJQuerySupportMailWebEngine()
 {
-
 }
 
 KMime::Message::Ptr TestJQuerySupportMailWebEngine::readAndParseMail(const QString &mailFile)
