@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,19 +24,27 @@
 #include "messageviewer_export.h"
 class KActionCollection;
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class ViewerPluginPrivate;
 class ViewerPluginInterface;
 class MESSAGEVIEWER_EXPORT ViewerPlugin : public QObject
 {
     Q_OBJECT
 public:
-    explicit ViewerPlugin(QObject *parent = Q_NULLPTR);
+    explicit ViewerPlugin(QObject *parent = nullptr);
     ~ViewerPlugin();
 
-    virtual MessageViewer::ViewerPluginInterface *createView(QWidget *parent, KActionCollection *ac) = 0;
+    virtual MessageViewer::ViewerPluginInterface *createView(QWidget *parent,
+                                                             KActionCollection *ac) = 0;
     virtual QString viewerPluginName() const = 0;
+    virtual void showConfigureDialog(QWidget *parent = nullptr);
+    virtual bool hasConfigureDialog() const;
+
+    void setIsEnabled(bool enabled);
+    bool isEnabled() const;
+
+Q_SIGNALS:
+    void configChanged();
 
 private:
     ViewerPluginPrivate *const d;
