@@ -39,17 +39,6 @@ const Interface::BodyPartFormatter *MailmanBodyPartFormatter::create()
     }
     return self;
 }
-Interface::BodyPartFormatter::Result MailmanBodyPartFormatter::format(Interface::BodyPart *part, HtmlWriter *writer) const
-{
-    Q_UNUSED(writer)
-    const auto p = process(*part);
-    const auto mp = static_cast<MessagePart *>(p.data());
-    if (mp) {
-        mp->html(false);
-        return Ok;
-    }
-    return Failed;
-}
 
 bool MailmanBodyPartFormatter::isMailmanMessage(KMime::Content *curNode) const
 {
