@@ -133,10 +133,10 @@ public:
     explicit CustomTemplateItemDelegate(QObject *parent = nullptr);
     ~CustomTemplateItemDelegate();
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const Q_DECL_OVERRIDE;
+                          const QModelIndex &index) const override;
 
     void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const Q_DECL_OVERRIDE;
+                      const QModelIndex &index) const override;
 
 };
 
