@@ -96,6 +96,7 @@ FindBarBase::FindBarBase(QWidget *parent)
 
     mStatus = new QLabel;
     mStatus->setObjectName(QStringLiteral("status"));
+    mStatus->setTextFormat(Qt::PlainText);
     QFontMetrics fm(mStatus->font());
     mNotFoundString = i18n("Phrase not found");
     mStatus->setFixedWidth(fm.width(mNotFoundString));
@@ -241,7 +242,7 @@ bool FindBarBase::event(QEvent *e)
     // Close the bar when pressing Escape.
     // Not using a QShortcut for this because it could conflict with
     // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
-    // With a shortcut Q_DECL_OVERRIDE we can catch this before it gets to kactions.
+    // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
         QKeyEvent *kev = static_cast<QKeyEvent * >(e);
