@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,19 +33,20 @@ class WEBENGINEVIEWER_EXPORT WebEnginePage : public QWebEnginePage
 {
     Q_OBJECT
 public:
-    explicit WebEnginePage(QObject *parent = Q_NULLPTR);
-    explicit WebEnginePage(QWebEngineProfile *profile, QObject *parent = Q_NULLPTR);
+    explicit WebEnginePage(QObject *parent = nullptr);
+    explicit WebEnginePage(QWebEngineProfile *profile, QObject *parent = nullptr);
 
     ~WebEnginePage();
     WebEngineViewer::WebHitTest *hitTestContent(const QPoint &pos);
-    QVariant execJavaScript(const QString &scriptSource, int timeout = 500);
 
     void saveHtml(QWebEngineDownloadItem *download);
 Q_SIGNALS:
     void urlClicked(const QUrl &url);
+    void showConsoleMessage(const QString &message);
 
 protected:
-    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) Q_DECL_OVERRIDE;
+    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
+    void javaScriptConsoleMessage(JavaScriptConsoleMessageLevel level, const QString &message, int lineNumber, const QString &sourceID) override;
 
 private:
     void init();
